"""Autogenerated API"""
from argus_api import session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
from requests import Response

log = logging.getLogger(__name__)


@register_command(
    extending=("currentuser", "v1", "picture"),
    module=argus_cli_module
)
def get_profile_picture(
    default: bool = None,
    json: bool = True,
    verify: bool = True,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
  ) -> Response:
    """Get current user's profile picture (PUBLIC)
    
    :param bool default: If true, return default avatar image if user picture not set. Default is false.:param json:
    :param verify: path to a certificate bundle or boolean indicating whether SSL
    verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ProfilePictureNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: requests.Response object
    
    """

    route = "/currentuser/v1/picture".format(default=default)

    headers = {
        'User-Agent': 'ArgusToolbelt/',
        'content': None
    }

    body = {}

    query_parameters = {}
    # Only send default if the argument was provided, dont send null values
    if default is not None:
        query_parameters.update({"default": default})

    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers
    )
    return response
    


@register_command(
    extending=("currentuser", "v1", "picture"),
    module=argus_cli_module
)
def update_profile_picture_json(
    image: str = None,
    mimeType: str = None,
    json: bool = True,
    verify: bool = True,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
  ) -> dict:
    """Set current user's profile picture (PUBLIC) (PUBLIC)
    
    :param str image: Image bytes 
    :param str mimeType: Image MIME type  => Sanitize by regex .+/.+:param json:
    :param verify: path to a certificate bundle or boolean indicating whether SSL
    verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ArgusException: on other status codes
    
    :returns dictionary translated from JSON
    """

    route = "/currentuser/v1/picture".format()

    headers = {
        'User-Agent': 'ArgusToolbelt/',
    }

    body = {}
    # Only send image if the argument was provided, dont send null values
    if image is not None:
        body.update({"image": image})
    # Only send mimeType if the argument was provided, dont send null values
    if mimeType is not None:
        body.update({"mimeType": mimeType})

    query_parameters = {}

    log.debug("PUT %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.put(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers
    )
    return response.json()

